# Generated by Django 5.1.6 on 2025-05-28 04:31

from django.db import migrations, models


class Migration(migrations.Migration):
    dependencies = [
        ("db", "0006_account_initialization_vector"),
    ]

    operations = [
        migrations.AlterField(
            model_name="account",
            name="encrpyted_seed",
            field=models.BinaryField(max_length=64),
        ),
        migrations.AlterField(
            model_name="account",
            name="initialization_vector",
            field=models.BinaryField(max_length=32),
        ),
    ]
