# Generated by Django 5.1.6 on 2025-05-28 04:47

from django.db import migrations


class Migration(migrations.Migration):
    dependencies = [
        ("db", "0007_alter_account_encrpyted_seed_and_more"),
    ]

    operations = [
        migrations.RenameField(
            model_name="account",
            old_name="encrpyted_seed",
            new_name="encrypted_seed",
        ),
    ]
