# Generated by Django 5.1.7 on 2025-05-24 00:38

from django.db import migrations, models


class Migration(migrations.Migration):
    dependencies = [
        ("db", "0003_alter_account_algorithm"),
    ]

    operations = [
        migrations.AddField(
            model_name="group",
            name="salt",
            field=models.BinaryField(
                default=b"2{u\x81N\x97\xe5e;\xbb\x0c\x13O\xa9\xf0\x9b", max_length=32
            ),
            preserve_default=False,
        ),
    ]
