# Generated by Django 5.1.6 on 2025-03-03 04:27

from django.db import migrations, models


class Migration(migrations.Migration):
    dependencies = [
        ("db", "0001_initial"),
    ]

    operations = [
        migrations.AddField(
            model_name="account",
            name="algorithm",
            field=models.CharField(
                choices=[("SHA1", "sha1"), ("SHA256", "sha256"), ("SHA512", "sha512")],
                default="SHA1",
                max_length=10,
            ),
        ),
        migrations.AddField(
            model_name="account",
            name="digits",
            field=models.IntegerField(default=6),
        ),
        migrations.AddField(
            model_name="account",
            name="period",
            field=models.IntegerField(default=30),
        ),
    ]
