# Generated by Django 5.1.7 on 2025-05-26 15:25

from django.db import migrations


class Migration(migrations.Migration):
    dependencies = [
        ("db", "0004_group_salt"),
    ]

    operations = [
        migrations.RenameField(
            model_name="account",
            old_name="seed",
            new_name="encrpyted_seed",
        ),
    ]
