# Generated by Django 5.1.6 on 2025-05-27 03:43

from django.db import migrations, models

import crypto


class Migration(migrations.Migration):
    dependencies = [
        ("db", "0005_rename_seed_account_encrpyted_seed"),
    ]

    operations = [
        migrations.AddField(
            model_name="account",
            name="initialization_vector",
            field=models.BinaryField(default=crypto.Crypto.random_bytes, max_length=32),
        ),
    ]
